aboutsummaryrefslogtreecommitdiffstats
path: root/src/pcm_mix.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/pcm_mix.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/pcm_mix.h b/src/pcm_mix.h
index 9b576f40d..10a07168f 100644
--- a/src/pcm_mix.h
+++ b/src/pcm_mix.h
@@ -20,9 +20,9 @@
#ifndef PCM_MIX_H
#define PCM_MIX_H
-#include <stddef.h>
+#include "audio_format.h"
-struct audio_format;
+#include <stddef.h>
/*
* Linearly mixes two PCM buffers. Both must have the same length and
@@ -33,13 +33,13 @@ struct audio_format;
* @param buffer1 the first PCM buffer, and the destination buffer
* @param buffer2 the second PCM buffer
* @param size the size of both buffers in bytes
* @param format the audio format of both buffers
* @param portion1 a number between 0.0 and 1.0 specifying the portion
* of the first buffer in the mix; portion2 = (1.0 - portion1). The value
* NaN is used by the MixRamp code to specify that simple addition is required.
*/
void
pcm_mix(void *buffer1, const void *buffer2, size_t size,
- const struct audio_format *format, float portion1);
+ enum sample_format format, float portion1);
#endif
@@ -33,13 +33,13 @@ struct audio_format;
* @param buffer2 the second PCM buffer
* @param size the size of both buffers in bytes
- * @param format the audio format of both buffers
+ * @param format the sample format of both buffers
* @param portion1 a number between 0.0 and 1.0 specifying the portion
* of the first buffer in the mix; portion2 = (1.0 - portion1). The value